@@ -38,21 +38,16 @@
 # include "exprChecks.h"
 # include "exprNodeSList.h"
 
-
 /*@access constraint, exprNode @*/ /*!!! NO! Don't do this so recklessly - design your code more carefully so you don't need to! */
 
-static constraint  inequalitySubstitute  (/*@returned@*/ constraint p_c, constraintList p_p);
-
-
+static constraint inequalitySubstitute (/*@returned@*/ constraint p_c, constraintList p_p);
 static bool rangeCheck (arithType p_ar1, /*@observer@*/ constraintExpr p_expr1, arithType p_ar2, /*@observer@*/ constraintExpr p_expr2);
 
-static constraint  inequalitySubstituteUnsound  (/*@returned@*/ constraint p_c, constraintList p_p);
-
-static constraint  inequalitySubstituteStrong  (/*@returned@*/ constraint p_c, constraintList p_p);
+static constraint inequalitySubstituteUnsound (/*@returned@*/ constraint p_c, constraintList p_p);
+static constraint inequalitySubstituteStrong (/*@returned@*/ constraint p_c, constraintList p_p);
 
 static constraint constraint_searchandreplace (/*@returned@*/ constraint p_c, constraintExpr p_old, constraintExpr p_newExpr);
 
-
 static constraint constraint_addOr (/*@returned@*/ constraint p_orig, /*@observer@*/ constraint p_orConstr);
 
 static bool resolveOr (/*@temp@*/constraint p_c, /*@observer@*/ /*@temp@*/ constraintList p_list);
@@ -79,7 +74,7 @@ static /*@only@*/ constraintList reflectChangesEnsuresFree1 (/*@only@*/ constrai
   llassert(constraintList_isDefined(list2) );
 
   DPRINTF(( message ("constraintList_mergeEnsures: list1 %s list2 %s",
-		     constraintList_print(list1), constraintList_print(list2)
+		     constraintList_unparse(list1), constraintList_unparse(list2)
 		     )));
   
   ret = constraintList_fixConflicts (list1, list2);
@@ -94,7 +89,7 @@ static /*@only@*/ constraintList reflectChangesEnsuresFree1 (/*@only@*/ constrai
   constraintList_free(ret);
   
   DPRINTF(( message ("constraintList_mergeEnsures: returning %s ",
-		     constraintList_print(temp) )
+		     constraintList_unparse(temp) )
 		     ));
   
 
@@ -118,7 +113,7 @@ static /*@only@*/ constraintList reflectChangesEnsuresFree1 (/*@only@*/ constrai
   constraintList ret;
   constraintList temp;
 
-  DPRINTF((message ("constraintList_mergeRequires: merging  %s and %s ", constraintList_print (list1), constraintList_print(list2) ) ) );
+  DPRINTF((message ("constraintList_mergeRequires: merging  %s and %s ", constraintList_unparse (list1), constraintList_unparse(list2) ) ) );
 
   if (context_getFlag (FLG_REDUNDANTCONSTRAINTS) )
     {
@@ -129,16 +124,16 @@ static /*@only@*/ constraintList reflectChangesEnsuresFree1 (/*@only@*/ constrai
     
   /* get constraints in list1 not satified by list2 */
   temp = constraintList_reflectChanges(list1, list2);
-  DPRINTF((message ("constraintList_mergeRequires: temp = %s", constraintList_print(temp) ) ) );
+  DPRINTF((message ("constraintList_mergeRequires: temp = %s", constraintList_unparse(temp) ) ) );
 
 /*get constraints in list2 not satified by temp*/
   ret = constraintList_reflectChanges(list2, temp);
  
-  DPRINTF((message ("constraintList_mergeRequires: ret =  %s", constraintList_print(ret) ) ) );
+  DPRINTF((message ("constraintList_mergeRequires: ret =  %s", constraintList_unparse(ret) ) ) );
   
   ret = constraintList_addListFree (ret, temp);
   
-  DPRINTF((message ("constraintList_mergeRequires: returning  %s", constraintList_print(ret) ) ) );
+  DPRINTF((message ("constraintList_mergeRequires: returning  %s", constraintList_unparse(ret) ) ) );
 
   return ret;
 }
@@ -171,8 +166,8 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
 
 	   parent->ensuresConstraints = constraintList_copy (child2->ensuresConstraints);
 	   DPRINTF((message ("Copied child constraints: pre: %s and post: %s",
-			     constraintList_print( child2->requiresConstraints),
-			     constraintList_print (child2->ensuresConstraints)
+			     constraintList_unparse( child2->requiresConstraints),
+			     constraintList_unparse (child2->ensuresConstraints)
 			     )
 		    ));
 	   return;
@@ -187,10 +182,10 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
    llassert(!exprNode_isError (child1)  && ! exprNode_isError(child2) );
    
    DPRINTF((message ("Child constraints are %s %s and %s %s",
-		     constraintList_print (child1->requiresConstraints),
-		     constraintList_print (child1->ensuresConstraints),
-		     constraintList_print (child2->requiresConstraints),
-		     constraintList_print (child2->ensuresConstraints)
+		     constraintList_unparse (child1->requiresConstraints),
+		     constraintList_unparse (child1->ensuresConstraints),
+		     constraintList_unparse (child2->requiresConstraints),
+		     constraintList_unparse (child2->ensuresConstraints)
 		     ) ) );
  
  
@@ -210,7 +205,7 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
   parent->requiresConstraints = temp2;
 
   DPRINTF((message ("Parent requires constraints are %s  ",
-		     constraintList_print (parent->requiresConstraints)
+		     constraintList_unparse (parent->requiresConstraints)
 		     ) ) );
 
    constraintList_free(parent->ensuresConstraints);
@@ -220,14 +215,11 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
 
   
   DPRINTF((message ("Parent constraints are %s and %s ",
-		     constraintList_print (parent->requiresConstraints),
-		     constraintList_print (parent->ensuresConstraints)
+		     constraintList_unparse (parent->requiresConstraints),
+		     constraintList_unparse (parent->ensuresConstraints)
 		     ) ) );
  
 }
-
-
-  
   
 /*@only@*/ constraintList constraintList_subsumeEnsures (constraintList list1, constraintList list2)
 {
@@ -236,7 +228,7 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
   constraintList_elements (list1, el)
     {
       
-      DPRINTF ((message ("Examining %s", constraint_print (el) ) ) );
+      DPRINTF ((message ("Examining %s", constraint_unparse (el) ) ) );
       if (!constraintList_resolve (el, list2) )
 	{
 	  constraint temp;
@@ -245,7 +237,7 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
 	}
       else
 	{
-	  DPRINTF ((message ("Subsuming %s", constraint_print (el) ) ) );
+	  DPRINTF ((message ("Subsuming %s", constraint_unparse (el) ) ) );
 	}
     } end_constraintList_elements;
 
@@ -267,8 +259,6 @@ void exprNode_mergeResolve (exprNode parent, exprNode child1, exprNode child2)
   return ret;
 }
 
-
-
 /* tries to resolve constraints in list pre2 using post1 */
 
 static /*@only@*/ constraintList reflectChangesNoOr (/*@observer@*/ /*@temp@*/ constraintList pre2, /*@observer@*/ /*@temp@*/ constraintList post1)
@@ -281,7 +271,7 @@ static /*@only@*/ constraintList reflectChangesNoOr (/*@observer@*/ /*@temp@*/ c
   llassert  (! context_getFlag (FLG_ORCONSTRAINT) );
 
   ret = constraintList_makeNew();
-  DPRINTF((message ("reflectChanges: lists %s and %s", constraintList_print(pre2), constraintList_print(post1) )));
+  DPRINTF((message ("reflectChanges: lists %s and %s", constraintList_unparse(pre2), constraintList_unparse(post1) )));
   
   constraintList_elements (pre2, el)
     {
@@ -313,7 +303,7 @@ static /*@only@*/ constraintList reflectChangesNoOr (/*@observer@*/ /*@temp@*/ c
 	}
     } end_constraintList_elements;
 
-    DPRINTF((message ("reflectChanges: returning %s", constraintList_print(ret) ) ) );
+    DPRINTF((message ("reflectChanges: returning %s", constraintList_unparse(ret) ) ) );
     return ret;
 }
 
@@ -339,7 +329,7 @@ static constraint constraint_addOr (/*@returned@*/ constraint orig, /*@observer@
   
   c = orig;
 
-  DPRINTF((message("constraint_addor: oring %s onto %s", constraint_printOr(orConstr), constraint_printOr(orig) ) ));
+  DPRINTF((message("constraint_addor: oring %s onto %s", constraint_unparseOr(orConstr), constraint_unparseOr(orig) ) ));
   
   while (c->or != NULL)
     {
@@ -348,7 +338,7 @@ static constraint constraint_addOr (/*@returned@*/ constraint orig, /*@observer@
   
   c->or = constraint_copy(orConstr);
 
-  DPRINTF((message("constraint_addor: returning %s",constraint_printOr(orig) ) ));
+  DPRINTF((message("constraint_addor: returning %s",constraint_unparseOr(orig) ) ));
   
   return orig;
 }
@@ -364,7 +354,7 @@ static bool resolveOr ( /*@temp@*/ constraint c, /*@observer@*/ /*@temp@*/ const
 
     llassert(constraint_isDefined(c) );
 
-  DPRINTF(( message("resolveOr: constraint %s and list %s", constraint_printOr(c), constraintList_print(list) ) ));
+  DPRINTF(( message("resolveOr: constraint %s and list %s", constraint_unparseOr(c), constraintList_unparse(list) ) ));
   
   temp = c;
 
@@ -390,7 +380,7 @@ static /*@only@*/ constraint doResolve (/*@only@*/ constraint c, constraintList
   llassert(constraint_isDefined (c ) );
 
   DPRINTF((message("doResolve:: call on constraint c = : %q and constraintList %q",
-		   constraint_printOr(c), constraintList_print(post1)
+		   constraint_unparseOr(c), constraintList_unparse(post1)
 		   )
 	   ));
   
@@ -400,7 +390,7 @@ static /*@only@*/ constraint doResolve (/*@only@*/ constraint c, constraintList
       temp = constraint_substitute (c, post1);
       
       DPRINTF((message("doResolve:: after substitute temp is %q",
-		   constraint_printOr(temp)
+		   constraint_unparseOr(temp)
 		       )
 	       ));
   
@@ -437,13 +427,13 @@ static /*@only@*/ constraint doResolve (/*@only@*/ constraint c, constraintList
 
 			  DPRINTF((
 				   message("doResolve: adding %s ",
-					   constraint_printOr(tempSub)
+					   constraint_unparseOr(tempSub)
 					   )
 				   ));
 			  
 			  DPRINTF((
 				   message("doResolve: not adding %s ",
-					   constraint_printOr(temp2)
+					   constraint_unparseOr(temp2)
 					   )
 				   ));
 			  
@@ -463,14 +453,14 @@ static /*@only@*/ constraint doResolve (/*@only@*/ constraint c, constraintList
 
 			  DPRINTF((
 				   message("doResolve: adding %s ",
-					   constraint_printOr(tempSub)
+					   constraint_unparseOr(tempSub)
 					   )
 				   ));
 
 			  
 			  DPRINTF((
 				   message("doResolve: not adding %s ",
-					   constraint_printOr(temp3)
+					   constraint_unparseOr(temp3)
 					   )
 				   ));
 
@@ -514,14 +504,11 @@ static /*@only@*/ constraint doResolveOr (/*@observer@*/ /*@temp@*/ constraint c
   constraint ret;
   constraint next;
   constraint curr;
-
   
-  DPRINTF(( message("doResolveOr: constraint %s and list %s", constraint_printOr(c), constraintList_print(post1) ) ));
-
+  DPRINTF(( message("doResolveOr: constraint %s and list %s", constraint_unparseOr(c), constraintList_unparse(post1) ) ));
 
+  *resolved = FALSE;
   
-   *resolved = FALSE;
-
   llassert(constraint_isDefined(c) );
 
   ret = constraint_copy(c);
@@ -571,6 +558,9 @@ static /*@only@*/ constraint doResolveOr (/*@observer@*/ /*@temp@*/ constraint c
       ret = constraint_addOr (ret, curr);
       constraint_free(curr);
     }
+
+  DPRINTF(( message("doResolveOr: returning ret = %s", constraint_unparseOr(ret) ) ));
+  
   return ret;
 }
 
@@ -581,7 +571,7 @@ static /*@only@*/ constraint doResolveOr (/*@observer@*/ /*@temp@*/ constraint c
   constraintList ret;
   constraint temp;
   ret = constraintList_makeNew();
-  DPRINTF((message ("constraintList_reflectChangesOr: lists %s and %s", constraintList_print(pre2), constraintList_print(post1) )));
+  DPRINTF((message ("constraintList_reflectChangesOr: lists %s and %s", constraintList_unparse(pre2), constraintList_unparse(post1) )));
   
   constraintList_elements (pre2, el)
     {
@@ -600,7 +590,7 @@ static /*@only@*/ constraint doResolveOr (/*@observer@*/ /*@temp@*/ constraint c
       
     } end_constraintList_elements;
 
-  DPRINTF((message ("constraintList_reflectChangesOr: returning %s", constraintList_print(ret) ) ) );
+  DPRINTF((message ("constraintList_reflectChangesOr: returning %s", constraintList_unparse(ret) ) ) );
     return ret;
 }
 
@@ -623,7 +613,7 @@ static /*@only@*/ constraintList reflectChangesEnsures (/*@observer@*/ constrain
 	}
       else
 	{
-	  DPRINTF ((message ("Resolved away %s ", constraint_print(el) ) ) );
+	  DPRINTF ((message ("Resolved away %s ", constraint_unparse(el) ) ) );
 	}
     } end_constraintList_elements;
 
@@ -645,21 +635,22 @@ static /*@only@*/ constraintList reflectChangesEnsuresFree1 (/*@only@*/ constrai
 
 static bool constraint_conflict (constraint c1, constraint c2)
 {
+  if (!constraint_isDefined(c1) || !constraint_isDefined(c2))
+    {
+      return FALSE;
+    }
 
-  llassert(constraint_isDefined(c1) );
-  llassert(constraint_isDefined(c2) );
-
-  if (constraintExpr_similar(c1->lexpr, c2->lexpr) )
+  if (constraintExpr_similar (c1->lexpr, c2->lexpr))
     {
       if (c1->ar == EQ)
 	if (c1->ar == c2->ar)
 	  {
-	    DPRINTF ((message ("%s conflicts with %s ", constraint_print (c1), constraint_print(c2) ) ) );
+	    DPRINTF (("%s conflicts with %s", constraint_unparse (c1), constraint_unparse (c2)));
 	    return TRUE;
 	  }
     }  
 
-  /* This is a slight kludg to prevent circular constraints like
+  /* This is a slight kludge to prevent circular constraints like
      strlen(str) == maxRead(s) + strlen(str);
   */
 
@@ -677,7 +668,7 @@ static bool constraint_conflict (constraint c1, constraint c2)
 
 	      if (constraintTerm_isExprNode(term) )
 		{
-		  DPRINTF ((message ("%s conflicts with %s ", constraint_print (c1), constraint_print(c2) ) ) );
+		  DPRINTF ((message ("%s conflicts with %s ", constraint_unparse (c1), constraint_unparse(c2) ) ) );
 		  return TRUE;
 		}
 	    }
@@ -685,11 +676,11 @@ static bool constraint_conflict (constraint c1, constraint c2)
 
   if (constraint_tooDeep(c1) || constraint_tooDeep(c2) )
     	{
-	  DPRINTF ((message ("%s conflicts with %s (constraint is too deep", constraint_print (c1), constraint_print(c2) ) ) );
+	  DPRINTF ((message ("%s conflicts with %s (constraint is too deep", constraint_unparse (c1), constraint_unparse(c2) ) ) );
 	  return TRUE;
 	}
   
-  DPRINTF ((message ("%s doesn't conflict with %s ", constraint_print (c1), constraint_print(c2) ) ) );
+  DPRINTF ((message ("%s doesn't conflict with %s ", constraint_unparse (c1), constraint_unparse(c2) ) ) );
 
   return FALSE; 
 
@@ -699,9 +690,10 @@ static void constraint_fixConflict (/*@temp@*/ constraint good, /*@temp@*/ /*@ob
 {
   llassert(constraint_isDefined(conflicting) );
   
-  if (conflicting->ar ==EQ )
+  if (conflicting->ar == EQ)
     {
-      llassert(constraint_isDefined(good) );
+      llassert (constraint_isDefined(good));
+      DPRINTF (("Replacing here!"));
       good->expr = constraintExpr_searchandreplace (good->expr, conflicting->lexpr, conflicting->expr);
       good = constraint_simplify (good);
     }
@@ -748,42 +740,60 @@ constraintList constraintList_fixConflicts (constraintList list1, constraintList
     return ret;
 }
 
-/*returns true if constraint post satifies cosntriant pre */
-static bool satifies (constraint pre, constraint post)
-{
-  llassert(constraint_isDefined(pre) );
-  llassert(constraint_isDefined(post) );
+/*returns true if constraint post satisfies cosntriant pre */
 
-  if (constraint_isAlwaysTrue (pre)  )
+static bool constraintResolve_satisfies (constraint pre, constraint post)
+{
+  if (!constraint_isDefined (pre))
+    {
+      return TRUE;
+    }
+
+  if (!constraint_isDefined(post)) 
+    {
+      return FALSE;
+    }
+
+  if (constraint_isAlwaysTrue (pre))
     return TRUE;
   
   if (!constraintExpr_similar (pre->lexpr, post->lexpr) )
     {
       return FALSE;
     }
+  
   if (constraintExpr_isUndefined(post->expr))
     {
       llassert(FALSE);
       return FALSE;
     }
-
+  
   return rangeCheck (pre->ar, pre->expr, post->ar, post->expr);
 }
 
 
-bool constraintList_resolve (/*@temp@*/ /*@observer@*/ constraint c, /*@temp@*/ /*@observer@*/ constraintList p)
+bool constraintList_resolve (/*@temp@*/ /*@observer@*/ constraint c,
+			     /*@temp@*/ /*@observer@*/ constraintList p)
 {
+  DPRINTF (("[resolve] Trying to resolve constraint: %s using %s",
+	    constraint_unparse (c),
+	    constraintList_unparse (p)));
+
   constraintList_elements (p, el)
     {
-      if ( satifies (c, el) )
+      if (constraintResolve_satisfies (c, el))
 	{
-	  DPRINTF ((message ("\n%s Satifies %s\n ", constraint_print(el), constraint_print(c) ) ) );
+	  DPRINTF (("constraintList_resolve: %s satifies %s", 
+		    constraint_unparse (el), constraint_unparse (c)));
 	  return TRUE;
 	}
-        DPRINTF ((message ("\n%s does not satify %s\n ", constraint_print(el), constraint_print(c) ) ) );
+      
+      DPRINTF (("constraintList_resolve: %s does not satify %s\n ", 
+		constraint_unparse (el), constraint_unparse (c)));
     }
   end_constraintList_elements;
-  DPRINTF ((message ("no constraints satify %s", constraint_print(c) ) ));
+
+  DPRINTF (("No constraints satify: %s", constraint_unparse (c)));
   return FALSE;
 }
 
@@ -793,7 +803,7 @@ static bool arithType_canResolve (arithType ar1, arithType ar2)
     {
     case GTE:
     case GT:
-      if ((ar2 == GT) || (ar2 == GTE) || (ar2 == EQ) )
+      if ((ar2 == GT) || (ar2 == GTE) || (ar2 == EQ))
 	{
 	  return TRUE;
 	}
@@ -806,7 +816,7 @@ static bool arithType_canResolve (arithType ar1, arithType ar2)
 
     case LT:
     case LTE:
-      if ((ar2 == LT) || (ar2 == LTE) || (ar2 == EQ) )
+      if ((ar2 == LT) || (ar2 == LTE) || (ar2 == EQ))
 	return TRUE;
       break;
     default:
@@ -816,7 +826,7 @@ static bool arithType_canResolve (arithType ar1, arithType ar2)
 }
 
 /*checks for the case expr2 == sizeof buf1  and buf1 is a fixed array*/
-static bool  sizeofBufComp(constraintExpr buf1, constraintExpr expr2)
+static bool sizeofBufComp(constraintExpr buf1, constraintExpr expr2)
 {
   constraintTerm ct;
   exprNode e, t;
@@ -837,9 +847,9 @@ static bool  sizeofBufComp(constraintExpr buf1, constraintExpr expr2)
 
   e = constraintTerm_getExprNode(ct);
 
-  llassert(exprNode_isDefined(e) );
+  llassert (exprNode_isDefined(e));
 
-  if (! (exprNode_isDefined(e) ) )
+  if (! (exprNode_isDefined(e)))
     return FALSE;
   
   if (e->kind != XPR_SIZEOF)
@@ -872,7 +882,7 @@ static bool sizeOfMaxSet( /*@observer@*/ /*@temp@*/ constraint c)
 {
   constraintExpr l, r, buf1, buf2, con;
 
-  DPRINTF(( message("sizeOfMaxSet: checking %s ", constraint_print(c) )
+  DPRINTF(( message("sizeOfMaxSet: checking %s ", constraint_unparse(c) )
 	    ));
 
   llassert (constraint_isDefined(c) );
@@ -963,7 +973,7 @@ bool constraint_isAlwaysTrue (/*@observer@*/ /*@temp@*/ constraint c)
   l = c->lexpr;
   r = c->expr;
 
-  DPRINTF(( message("constraint_IsAlwaysTrue:examining %s", constraint_print(c) ) ));
+  DPRINTF(( message("constraint_IsAlwaysTrue:examining %s", constraint_unparse(c) ) ));
 
   if (sizeOfMaxSet(c) )
     return TRUE;
@@ -992,7 +1002,7 @@ bool constraint_isAlwaysTrue (/*@observer@*/ /*@temp@*/ constraint c)
 	}
     }
 
-  if (constraintExpr_similar (l,r) )
+  if (constraintExpr_similar (l,r))
     {
       switch (c->ar)
 	{
@@ -1018,8 +1028,8 @@ bool constraint_isAlwaysTrue (/*@observer@*/ /*@temp@*/ constraint c)
 
   if (constraintExpr_similar (l,r) && (rHasConstant ) )
     {
-      DPRINTF(( message("constraint_IsAlwaysTrue: after removing constants  %s and %s are similar", constraintExpr_unparse(l), constraintExpr_unparse(r) ) ));
-      DPRINTF(( message("constraint_IsAlwaysTrue: rconstant is  %d", rConstant ) ));
+      DPRINTF(( message("constraint_IsAlwaysTrue: after removing constants %s and %s are similar", constraintExpr_unparse(l), constraintExpr_unparse(r) ) ));
+      DPRINTF(( message("constraint_IsAlwaysTrue: rconstant is %d", rConstant ) ));
       
       constraintExpr_free(l);
       constraintExpr_free(r);
@@ -1047,7 +1057,7 @@ bool constraint_isAlwaysTrue (/*@observer@*/ /*@temp@*/ constraint c)
       {
 	constraintExpr_free(l);
 	constraintExpr_free(r);
-	DPRINTF(( message("Constraint %s is not always true", constraint_print(c) ) ));
+	DPRINTF(( message("Constraint %s is not always true", constraint_unparse(c) ) ));
 	return FALSE;
       }
   
@@ -1057,125 +1067,127 @@ bool constraint_isAlwaysTrue (/*@observer@*/ /*@temp@*/ constraint c)
 static bool rangeCheck (arithType ar1, /*@observer@*/ constraintExpr expr1, arithType ar2, /*@observer@*/ constraintExpr expr2)
 
 {
-  DPRINTF ((message ("Doing Range CHECK %s and %s", constraintExpr_unparse(expr1), constraintExpr_unparse(expr2) ) ));
+  DPRINTF (("Doing range check %s and %s",
+	    constraintExpr_unparse (expr1), constraintExpr_unparse (expr2)));
 
-  if (! arithType_canResolve (ar1, ar2) )
+  if (!arithType_canResolve (ar1, ar2))
     return FALSE;
   
   switch (ar1)
- {
- case GTE:
-       if (constraintExpr_similar (expr1, expr2) )
-	  return TRUE;
-       /*@fallthrough@*/
-  case GT:
-    if (!  (constraintExpr_canGetValue (expr1) &&
-	       constraintExpr_canGetValue (expr2) ) )
-           {
-	          constraintExpr e1, e2;
-	          bool p1, p2;
-	          int const1, const2;
-
-	          e1 = constraintExpr_copy(expr1);
-	          e2 = constraintExpr_copy(expr2);
-
-	          e1 = constraintExpr_propagateConstants (e1, &p1, &const1);
-
-	          e2 = constraintExpr_propagateConstants (e2, &p2, &const2);
-
-	          if (p1 || p2)
-		     {
-		      if (!p1)
-			   const1 = 0;
-
-		      if (!p2)
-			   const2 = 0;
-
-		      if (const1 <= const2)
-			   if (constraintExpr_similar (e1, e2) )
-			          {
-				         constraintExpr_free(e1);
-				         constraintExpr_free(e2);
-				         return TRUE;
-				       }
-		      }
-	          DPRINTF(("Can't Get value"));
-
-	          constraintExpr_free(e1);
-	          constraintExpr_free(e2);
-	          return FALSE;
-	        }
-
-    if (constraintExpr_compare (expr2, expr1) >= 0)
-           return TRUE;
-
-   return FALSE;
-  case EQ:
-    if (constraintExpr_similar (expr1, expr2) )
-       return TRUE;
-
-    return FALSE;
-  case LTE:
-    if (constraintExpr_similar (expr1, expr2) )
-       return TRUE;
-    /*@fallthrough@*/
-  case LT:
-     if (!  (constraintExpr_canGetValue (expr1) &&
-	        constraintExpr_canGetValue (expr2) ) )
-            {
-	          constraintExpr e1, e2;
-	           bool p1, p2;
-	           int const1, const2;
-
-	           e1 = constraintExpr_copy(expr1);
-	           e2 = constraintExpr_copy(expr2);
-
-	           e1 = constraintExpr_propagateConstants (e1, &p1, &const1);
-
-	           e2 = constraintExpr_propagateConstants (e2, &p2, &const2);
-
-	           if (p1 || p2)
-		      {
-		       if (!p1)
-			    const1 = 0;
-
-		       if (!p2)
-			    const2 = 0;
-
-		       if (const1 >= const2)
-			    if (constraintExpr_similar (e1, e2) )
-			           {
-				          constraintExpr_free(e1);
-				          constraintExpr_free(e2);
-				          return TRUE;
-				        }
-		       }
-	           constraintExpr_free(e1);
-	           constraintExpr_free(e2);
-
-	           DPRINTF(("Can't Get value"));
-	           return FALSE;
-	         }
-
-    if (constraintExpr_compare (expr2, expr1) <= 0)
-           return TRUE;
-
-    return FALSE;
-
-  default:
+    {
+    case GTE:
+      if (constraintExpr_similar (expr1, expr2) )
+	return TRUE;
+      /*@fallthrough@*/
+    case GT:
+      if (!  (constraintExpr_canGetValue (expr1) &&
+	      constraintExpr_canGetValue (expr2) ) )
+	{
+	  constraintExpr e1, e2;
+	  bool p1, p2;
+	  int const1, const2;
+	  
+	  e1 = constraintExpr_copy(expr1);
+	  e2 = constraintExpr_copy(expr2);
+	  
+	  e1 = constraintExpr_propagateConstants (e1, &p1, &const1);
+	  e2 = constraintExpr_propagateConstants (e2, &p2, &const2);
+	  
+	  if (p1 || p2)
+	    {
+	      if (!p1)
+		const1 = 0;
+	      
+	      if (!p2)
+		const2 = 0;
+	      
+	      if (const1 <= const2)
+		if (constraintExpr_similar (e1, e2) )
+		  {
+		    constraintExpr_free(e1);
+		    constraintExpr_free(e2);
+		    return TRUE;
+		  }
+	    }
+	  DPRINTF(("Can't Get value"));
+	  
+	  constraintExpr_free(e1);
+	  constraintExpr_free(e2);
+	  return FALSE;
+	}
+      
+      if (constraintExpr_compare (expr2, expr1) >= 0)
+	return TRUE;
+      
+      return FALSE;
+    case EQ:
+      if (constraintExpr_similar (expr1, expr2) )
+	return TRUE;
+      
+      return FALSE;
+    case LTE:
+      if (constraintExpr_similar (expr1, expr2) )
+	return TRUE;
+      /*@fallthrough@*/
+    case LT:
+      if (!  (constraintExpr_canGetValue (expr1) &&
+	      constraintExpr_canGetValue (expr2) ) )
+	{
+	  constraintExpr e1, e2;
+	  bool p1, p2;
+	  int const1, const2;
+	  
+	  e1 = constraintExpr_copy(expr1);
+	  e2 = constraintExpr_copy(expr2);
+	  
+	  e1 = constraintExpr_propagateConstants (e1, &p1, &const1);
+	  
+	  e2 = constraintExpr_propagateConstants (e2, &p2, &const2);
+	  
+	  if (p1 || p2)
+	    {
+	      if (!p1)
+		const1 = 0;
+	      
+	      if (!p2)
+		const2 = 0;
+	      
+	      if (const1 >= const2)
+		if (constraintExpr_similar (e1, e2) )
+		  {
+		    constraintExpr_free(e1);
+		    constraintExpr_free(e2);
+		    return TRUE;
+		  }
+	    }
+	  constraintExpr_free(e1);
+	  constraintExpr_free(e2);
+	  
+	  DPRINTF(("Can't Get value"));
+	  return FALSE;
+	}
+      
+      if (constraintExpr_compare (expr2, expr1) <= 0)
+	return TRUE;
+      
+      return FALSE;
+      
+    default:
       llcontbug((message("Unhandled case in switch: %q", arithType_print(ar1) ) ) );
-  }
+    }
   BADEXIT;
 }
 
 static constraint constraint_searchandreplace (/*@returned@*/ constraint c, constraintExpr old, constraintExpr newExpr)
 {
-   llassert (constraint_isDefined(c)  );
-
-  DPRINTF (("Doing replace for lexpr") );
+  llassert (constraint_isDefined(c));
   
+  DPRINTF (("Starting replace lexpr [%p]: %s < %s ==> %s > in %s", c, 
+	    constraintExpr_unparse (c->lexpr), 
+	    constraintExpr_unparse (old), constraintExpr_unparse (newExpr),
+	    constraint_unparse (c)));
   c->lexpr = constraintExpr_searchandreplace (c->lexpr, old, newExpr);
-  DPRINTF (("Doing replace for expr") );
+  DPRINTF (("Finished replace lexpr [%p]: %s", c, constraintExpr_unparse (c->lexpr)));
   c->expr = constraintExpr_searchandreplace (c->expr, old, newExpr);
   return c;
 }
@@ -1185,7 +1197,7 @@ bool constraint_search (constraint c, constraintExpr old) /*@*/
   bool ret;
   ret = FALSE;
   
-  llassert (constraint_isDefined(c)  );
+  llassert (constraint_isDefined (c));
   
   ret  = constraintExpr_search (c->lexpr, old);
   ret = ret || constraintExpr_search (c->expr, old);
@@ -1197,23 +1209,23 @@ static constraint constraint_adjust (/*@returned@*/ constraint substitute, /*@ob
 {
   fileloc loc1, loc2, loc3;
 
-  DPRINTF ((message("Start adjust on %s and %s", constraint_print(substitute),
-		     constraint_print(old))
+  DPRINTF ((message("Start adjust on %s and %s", constraint_unparse(substitute),
+		     constraint_unparse(old))
 		   ));
 
   llassert(constraint_isDefined(substitute));
   llassert(constraint_isDefined(old));
 	   
   loc1 = constraint_getFileloc (old);
-  loc2 = constraintExpr_getFileloc (substitute->lexpr);
-  loc3 = constraintExpr_getFileloc (substitute->expr);
+  loc2 = constraintExpr_loc (substitute->lexpr);
+  loc3 = constraintExpr_loc (substitute->expr);
   
   /* special case of an equality that "contains itself" */
   if (constraintExpr_search (substitute->expr, substitute->lexpr) )
       if (fileloc_closer (loc1, loc3, loc2))
       {
 	constraintExpr temp;
-	DPRINTF ((message("Doing adjust on %s", constraint_print(substitute) )
+	DPRINTF ((message("Doing adjust on %s", constraint_unparse(substitute) )
 		   ));
 	temp = substitute->lexpr;
 	substitute->lexpr = substitute->expr;
@@ -1256,7 +1268,7 @@ constraint  inequalitySubstitute  (/*@returned@*/ constraint c, constraintList p
 	       {
 		 DPRINTF((message ("inequalitySubstitute Replacing %q in %q with  %q",
 				   constraintExpr_print (c->expr),
-				   constraint_print (c),
+				   constraint_unparse (c),
 				   constraintExpr_print (el->expr) )
 			  ));
 		 temp2   = constraintExpr_copy (el->lexpr);
@@ -1286,7 +1298,7 @@ constraint  inequalitySubstitute  (/*@returned@*/ constraint c, constraintList p
 
 static constraint  inequalitySubstituteStrong  (/*@returned@*/ constraint c, constraintList p)
 {
-  DPRINTF (( message ("inequalitySubstituteStrong examining substituting for %q", constraint_print(c) ) ));      
+  DPRINTF (( message ("inequalitySubstituteStrong examining substituting for %q", constraint_unparse(c) ) ));      
 
   llassert(constraint_isDefined(c) );
 
@@ -1299,11 +1311,11 @@ static constraint  inequalitySubstituteStrong  (/*@returned@*/ constraint c, con
     return c;
   
   DPRINTF (( message ("inequalitySubstituteStrong examining substituting for %q with %q",
-		      constraint_print(c), constraintList_print(p) ) ));      
+		      constraint_unparse(c), constraintList_unparse(p) ) ));      
   constraintList_elements (p, el)
     {
       
-      DPRINTF (( message ("inequalitySubstituteStrong examining substituting %s on %s", constraint_print(el), constraint_print(c) ) ));      
+      DPRINTF (( message ("inequalitySubstituteStrong examining substituting %s on %s", constraint_unparse(el), constraint_unparse(c) ) ));      
 
       llassert(constraint_isDefined(el) );
       if ((el->ar == LT ) ||  (el->ar == LTE )  )
@@ -1314,7 +1326,7 @@ static constraint  inequalitySubstituteStrong  (/*@returned@*/ constraint c, con
 	       {
 		 DPRINTF((message ("inequalitySubstitute Replacing %s in %s with  %s",
 				   constraintExpr_print (c->expr),
-				   constraint_print (c),
+				   constraint_unparse (c),
 				   constraintExpr_print (el->expr) )
 			  ));
 		 temp2   = constraintExpr_copy (el->expr);
@@ -1359,7 +1371,7 @@ static constraint  inequalitySubstituteUnsound  (/*@returned@*/ constraint c, co
 
       llassert(constraint_isDefined(el) );
 
-      DPRINTF (( message ("inequalitySubstituteUnsound examining substituting %s on %s", constraint_print(el), constraint_print(c) ) ));      
+      DPRINTF (( message ("inequalitySubstituteUnsound examining substituting %s on %s", constraint_unparse(el), constraint_unparse(c) ) ));      
        if (( el->ar == LTE) || (el->ar == LT) )
 	   {
 	     constraintExpr  temp2;
@@ -1386,41 +1398,34 @@ static constraint  inequalitySubstituteUnsound  (/*@returned@*/ constraint c, co
 
 /*@only@*/ constraint constraint_substitute (/*@observer@*/ /*@temp@*/ constraint c, constraintList p)
 {
-  constraint ret;
+  constraint ret = constraint_copy (c);
 
-  ret = constraint_copy(c);
   constraintList_elements (p, el)
     {
-      llassert(constraint_isDefined(el) );
-       if ( el->ar == EQ)
-	 if (!constraint_conflict (ret, el) )
-
-	   {
-	     constraint temp;
-	     
-	     temp = constraint_copy(el);
-	     
-	     temp = constraint_adjust(temp, ret);
-
-	     llassert(constraint_isDefined(temp) );
-
-	     
-	     DPRINTF((message ("constraint_substitute :: Substituting in %s using %s",
-			       constraint_print (ret), constraint_print (temp)
-			       ) ) );
-			       
+      if (constraint_isDefined (el))
+	{
+	  if ( el->ar == EQ)
+	    if (!constraint_conflict (ret, el))
+	      {
+		constraint temp = constraint_copy(el);
+		temp = constraint_adjust(temp, ret);
+		
+		llassert(constraint_isDefined(temp) );
+		
+		
+		DPRINTF (("constraint_substitute :: Substituting in %s using %s",
+			  constraint_unparse (ret), constraint_unparse (temp)));
 	  
-	     ret = constraint_searchandreplace (ret, temp->lexpr, temp->expr);
-	     DPRINTF(( message (" constraint_substitute :: The new constraint is %s", constraint_print (ret) ) ));
-	     constraint_free(temp);
-	   }
+		ret = constraint_searchandreplace (ret, temp->lexpr, temp->expr);
+		DPRINTF (("constraint_substitute :: The new constraint is %s", constraint_unparse (ret)));;
+		constraint_free(temp);
+	      }
+	}
     }
   end_constraintList_elements;
 
-  ret = constraint_simplify(ret);
-
-  DPRINTF(( message (" constraint_substitute :: The final new constraint is %s", constraint_print (ret) ) ));
-
+  ret = constraint_simplify (ret);
+  DPRINTF(( message (" constraint_substitute :: The final new constraint is %s", constraint_unparse (ret) ) ));
   return ret;
 }
 
@@ -1463,9 +1468,9 @@ static constraint constraint_solve (/*@returned@*/ constraint c)
 
   llassert(constraint_isDefined(c) );
 
-  DPRINTF((message ("Solving %s\n", constraint_print(c) ) ) );
+  DPRINTF((message ("Solving %s\n", constraint_unparse(c) ) ) );
   c->expr = constraintExpr_solveBinaryExpr (c->lexpr, c->expr);
-  DPRINTF((message ("Solved and got %s\n", constraint_print(c) ) ) );
+  DPRINTF((message ("Solved and got %s\n", constraint_unparse(c) ) ) );
 
   return c;
 }
@@ -1511,11 +1516,11 @@ constraint constraint_simplify ( /*@returned@*/ constraint c)
   
   llassert(constraint_isDefined(c) );
 	
-  DPRINTF(( message("constraint_simplify on %q ", constraint_print(c) ) ));
+  DPRINTF(( message("constraint_simplify on %q ", constraint_unparse(c) ) ));
 
   if (constraint_tooDeep(c))
     {
-        DPRINTF(( message("constraint_simplify: constraint to complex aborting %q ", constraint_print(c) ) ));
+        DPRINTF(( message("constraint_simplify: constraint to complex aborting %q ", constraint_unparse(c) ) ));
       return c;
 
     }
@@ -1538,7 +1543,7 @@ constraint constraint_simplify ( /*@returned@*/ constraint c)
       c = constraint_simplify(c);
     }
 
-  DPRINTF(( message("constraint_simplify returning  %q ", constraint_print(c) ) ));
+  DPRINTF(( message("constraint_simplify returning  %q ", constraint_unparse(c) ) ));
 
   return c;
 }
